<?php
/**
 *
 * Lonesome主题添加其他功能-function.php
 *
 */

function Lonesome_setup() {
	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// Enable support for Post Thumbnails
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'widget-thumb', 40, 40, true );
	set_post_thumbnail_size( 409, 160, true );

	// Enable support for meta title tag
	add_theme_support( 'title-tag' );

	// Switch default core markup for search form, comment form, and comments to output valid HTML5.
	add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'gallery', 'caption' ) );

	// Enable support for custom logo.
	add_theme_support( 'custom-logo' );

	register_nav_menus( array(
		'primary'      => esc_html__( '主菜单', 'Lonesome' ),
		'top_bar_left' => esc_html__( '头部菜单', 'Lonesome' ),
		'single_footer' => esc_html__( '文章底部菜单', 'Lonesome' ),
	) );
}
add_action( 'after_setup_theme', 'Lonesome_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function Lonesome_content_width() {
	$GLOBALS['content_width'] = 870;
}
add_action( 'after_setup_theme', 'Lonesome_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function Lonesome_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( '侧边栏', 'Lonesome' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<div class="widget %2$s" id="%1$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title"><span>',
		'after_title'   => '</span></h4>',
	) );
}
add_action( 'widgets_init', 'Lonesome_widgets_init' );

/**
 * Custom functions for excerpt.
 */
require get_template_directory() . '/inc/excerpt.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom theme widgets.
 */
require get_template_directory() . '/inc/widgets/widgets.php';

/**
 * Custom media functions.
 */
require get_template_directory() . '/inc/media.php';

// 加载 AJAX 评论
require get_template_directory() . '/inc/ajax-comment.php';

// 增加主题设置
require get_template_directory() . '/inc/theme-options.php';

// wp-clean-up插件集成
require get_template_directory() . '/inc/wp-clean-up/wp-clean-up.php';

// 自定义登录页面的LOGO链接为首页链接
    add_filter('login_headerurl', create_function(false, "return get_bloginfo('url');"));

// 增加链接管理
    add_filter('pre_option_link_manager_enabled', '__return_true');

// mail_Lonesome评论邮件提醒
	function comment_mail_Lonesome($comment_id) {
	$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
	$comment = get_comment($comment_id);
	$parent_id = $comment->comment_parent ? $comment->comment_parent : '';
	$spam_confirmed = $comment->comment_approved;
	if (($parent_id != '') && ($spam_confirmed != 'spam')) {
	$wp_email = 'no-reply@' . preg_replace('#^www\.#', '', strtolower($_SERVER['SERVER_NAME']));
	$to = trim(get_comment($parent_id)->comment_author_email);
	$subject = '您在 [' . $blogname . '] 中的留言有了新的回复';
	$message = '<div style="color:#555;font:12px/1.5 微软雅黑,Tahoma,Helvetica,Arial,sans-serif;width:650px;margin:50px auto;border-top: none;box-shadow:0 0px 3px #aaaaaa;" ><table border="0" cellspacing="0" cellpadding="0"><tbody><tr valign="top" height="2"><td valign="top"><div style="background-color:white;border-top:2px solid #12ADDB;box-shadow:0 1px 3px #AAAAAA;line-padding:0 15px 12px;width:650px;color:#555555;font-family:微软雅黑, Arial;;font-size:12px;"><h2 style="border-bottom:1px solid #DDD;font-size:14px;font-weight:normal;padding:8px 0 10px 8px;"><span style="color: #12ADDB;font-weight: bold;">&gt; </span>您在 <a style="text-decoration:none; color:#58B5F5;font-weight:600;" href="' . home_url() . '">' . $blogname . '</a> 博客上的留言有回复啦！</h2><div style="padding:0 12px 0 12px;margin-top:18px">
	<p>您好, ' . trim(get_comment($parent_id)->comment_author) . '! 您发表在文章 《' . get_the_title($comment->comment_post_ID) . '》 的评论:</p>
	<p style="background-color: #EEE;border: 1px solid #DDD;padding: 20px;margin: 15px 0;">' . nl2br(strip_tags(get_comment($parent_id)->comment_content)) . '</p>
	<p>' . trim($comment->comment_author) . ' 给您的回复如下:</p>
	<p style="background-color: #EEE;border: 1px solid #DDD;padding: 20px;margin: 15px 0;">' . nl2br(strip_tags($comment->comment_content)) . '</p>
	<p>您可以点击 <a style="text-decoration:none; color:#5692BC" href="' . htmlspecialchars(get_comment_link($parent_id)) . '">这里查看回复的完整內容</a>，也欢迎再次光临 <a style="text-decoration:none; color:#5692BC"
	href="' . home_url() . '">' . $blogname . '</a>。祝您天天开心，欢迎下次再次访问！谢谢。</p>
	<p style="padding-bottom: 15px;">(此邮件由系统自动发出, 请勿回复)</p></div></div></td></tr></tbody></table></div>';
	$from = "From: \"" . get_option('blogname') . "\" <$wp_email>";
	$headers = "$from\nContent-Type: text/html; charset=" . get_option('blog_charset') . "\n";
	wp_mail( $to, $subject, $message, $headers );
	}}

	add_action('comment_post', 'comment_mail_Lonesome');


//后台登陆数学验证码
    function myplugin_add_login_fields() {
        $num1 = rand(0, 9);
        $num2 = rand(0, 9);
        echo "<p><label for='math' class='small'>验证码</label><br /> $num1 + $num2 = ?<input type='text' name='sum' class='input' value='' size='25' tabindex='4'>"
        . "<input type='hidden' name='num1' value='$num1'>"
        . "<input type='hidden' name='num2' value='$num2'></p>";
    }

    add_action('login_form', 'myplugin_add_login_fields');

    function login_val() {
        $sum = $_POST['sum'];
        switch ($sum) {
            case $_POST['num1'] + $_POST['num2']:break;
            case null:wp_die('错误: 请输入验证码.');
                break;
            default:wp_die('错误: 验证码错误,请重试.');
        }
    }

    add_action('login_form_login', 'login_val');

// 禁止WordPress头部加载s.w.org
	function remove_dns_prefetch( $hints, $relation_type ) {
	if ( 'dns-prefetch' === $relation_type ) {
	return array_diff( wp_dependencies_unique_hosts(), $hints );
	}
	return $hints;
	}

	add_filter( 'wp_resource_hints', 'remove_dns_prefetch', 10, 2 );

// 移除后台 Google Font API
	function remove_open_sans_from_wp_core() {
	    wp_deregister_style('open-sans');
	    wp_register_style('open-sans', FALSE);
	    wp_enqueue_style('open-sans', '');
	}

	add_action('init', 'remove_open_sans_from_wp_core');

// 精简 wp_head & 去除无用函数 & 半角转全角
	remove_action('wp_head', 'feed_links', 2);
	remove_action('wp_head', 'feed_links_extra', 3);
	remove_action('wp_head', 'rsd_link');
	remove_action('wp_head', 'wlwmanifest_link');
	remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
	remove_action('wp_head', 'wp_generator');
	remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0);
	remove_filter('the_content', 'wptexturize');
	remove_filter('the_content', 'capital_P_dangit', 11);
	remove_filter('the_title', 'capital_P_dangit', 11);
	remove_filter('wp_title', 'capital_P_dangit', 11);
	remove_filter('comment_text', 'capital_P_dangit', 31);

// 评论链接跳转&新窗口打开
    function add_redirect_comment_link($text = '') {
        $text = str_replace("href='", "href='" . get_option('home') . "/?r=", $text);
        $text = preg_replace('/<a (.+?)>/i', "<a $1 target='_blank'>", $text);
        return $text;
    }

    function redirect_comment_link() {
        $redirect = $_GET['r'];
        if ($redirect) {
            if (strpos($_SERVER['HTTP_REFERER'], get_option('home')) !== false) {
                header("Location: $redirect");
                exit;
            } else {
                header("Location: " . bloginfo('url') . "/");
                exit;
            }
        }
    }

    add_action('init', 'redirect_comment_link');
    add_filter('get_comment_author_link', 'add_redirect_comment_link', 5);

// @父评论
    add_filter('comment_text', 'comment_add_at_parent');

    function comment_add_at_parent($comment_text) {
        $comment_ID = get_comment_ID();
        $comment = get_comment($comment_ID);
        if ($comment->comment_parent) {
            $parent_comment = get_comment($comment->comment_parent);
            $comment_text = '<a href="#comment-' . $comment->comment_parent . '">@' . $parent_comment->comment_author . '</a> ' . $comment_text;
        }
        return $comment_text;
    }

// 后台文本编辑器增加按钮
	function download($atts, $content = null) {
		return '<i class="icon-download"></i><a class="download" href="'.$content.'" rel="external" target="_blank" title="下载地址">下载地址</a>';}

		add_shortcode("download", "download"); 

		add_action('after_wp_tiny_mce', 'bolo_after_wp_tiny_mce');

		function bolo_after_wp_tiny_mce($mce_settings) {
		?>  
			<script type="text/javascript">  
				QTags.addButton( 'download', '下载按钮', "[download]下载地址[/download]" );
			    QTags.addButton('hr', '横线', "<hr />\n");//添加横线
	            QTags.addButton('h3', 'H3标签', "<h3>", "</h3>\n"); //添加标题3
	            QTags.addButton('h4', 'H4标签', "<h4>", "</h4>\n"); //添加标题4
	            QTags.addButton('sb', '上标', "<sup>", "</sup>");
	            QTags.addButton('xb', '下标', "<sub>", "</sub>");
	            QTags.addButton('shsj', '首行缩进', "&nbsp;&nbsp;");
	            QTags.addButton('hc', '回车', "<br />");
	            QTags.addButton('jz', '居中', "<center>", "</center>");
	            QTags.addButton('mark', '黄字', "<mark>", "</mark>");
	            QTags.addButton('xhx', '下划线', "<u>", "</u>");
	            QTags.addButton('pre', '代码', "<pre>", "</pre>\n"); //添加代码
	            QTags.addButton('embed', '文章引用', "[Lonesome_insert_post ids=文章id]");
			function bolo_QTnextpage_arg1() {
			}  
			</script>
		<?php 
	}

// 友情链接
	function get_the_link_items($id = null){
	    $bookmarks = get_bookmarks('orderby=date&category=' . $id);
	    $output    = '';
	    if (!empty($bookmarks)) {
	        $output .= '<div class="catalog-share">' . count($bookmarks) . ' items in collection</div><div class="userItems">';
	        foreach ($bookmarks as $bookmark) {
	            $output .= '<div class="userItem"><div class="userItem--inner"><div class="userItem-content">'. get_avatar($bookmark->link_notes,64) . '
	            <div class="userItem-name"><a class="link link--primary" href="' . $bookmark->link_url . '" target="_blank" >' . $bookmark->link_name . '</a></div></div></div></div>';
	        }
	        $output .= '</div>';
	    }
	    return $output;
	}

	function get_link_items(){
	    $linkcats = get_terms('link_category');
	    if (!empty($linkcats)) {
	        foreach ($linkcats as $linkcat) {
	            $result .= '
	            <h3 class="catalog-title">' . $linkcat->name . '</h3><div class="catalog-description">' . $linkcat->description . '</div>
	            ';
	            $result .= get_the_link_items($linkcat->term_id);
	        }
	    } else {
	        $result = get_the_link_items();
	    }
	    return $result;
	}

// 后台登录头像
	function custom_login_logo() {
		echo '<style type="text/css">
		h1 a { background-image:url('. esc_html( get_option( 'Lonesome_logo') ) .') !important;}
		</style>';
		}
	add_action('login_head', 'custom_login_logo');

// 禁用 emoji's表情
     function disable_emojis() {
	     remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	     remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	     remove_action( 'wp_print_styles', 'print_emoji_styles' );
	     remove_action( 'admin_print_styles', 'print_emoji_styles' );
	     remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
	     remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );
	     remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
	     add_filter( 'tiny_mce_plugins', 'disable_emojis_tinymce' );
     }
     add_action( 'init', 'disable_emojis' );

// 去除emojis wpemoji插件
     function disable_emojis_tinymce( $plugins ) {
	     if ( is_array( $plugins ) ) {
	     return array_diff( $plugins, array( 'wpemoji' ) );
	     } else {
	     return array();
	     }
     }

//禁用REST API/移除wp-json链接
    add_filter('rest_enabled', '__return_false');
    add_filter('rest_jsonp_enabled', '__return_false');
    remove_action( 'wp_head', 'rest_output_link_wp_head', 10 );
    remove_action( 'wp_head', 'wp_oembed_add_discovery_links', 10 );

//替换Gravatar头像库
	function Lonesome_get_ssl_avatar($avatar) {
	    $avatar = str_replace(array("www.gravatar.com", "0.gravatar.com", "1.gravatar.com", "2.gravatar.com"), "secure.gravatar.com", $avatar);
	    return $avatar;
	}
	add_filter('get_avatar', 'Lonesome_get_ssl_avatar');

// 取当前主题下smilies\下表情图片路径
    function custom_smilie9s_src($old, $img) {
        return get_stylesheet_directory_uri() . '/smilies/' . $img;
    }

    function init_smilie9s() {
        global $wpsmiliestrans;
        //默认表情文本与表情图片的对应关系(可自定义修改)
        $wpsmiliestrans = array(
            ':mrgreen:' => 'icon_mrgreen.gif',
            ':neutral:' => 'icon_neutral.gif',
            ':twisted:' => 'icon_twisted.gif',
            ':arrow:' => 'icon_arrow.gif',
            ':shock:' => 'icon_eek.gif',
            ':smile:' => 'icon_smile.gif',
            ':???:' => 'icon_confused.gif',
            ':cool:' => 'icon_cool.gif',
            ':evil:' => 'icon_evil.gif',
            ':grin:' => 'icon_biggrin.gif',
            ':idea:' => 'icon_idea.gif',
            ':oops:' => 'icon_redface.gif',
            ':razz:' => 'icon_razz.gif',
            ':roll:' => 'icon_rolleyes.gif',
            ':wink:' => 'icon_wink.gif',
            ':cry:' => 'icon_cry.gif',
            ':eek:' => 'icon_surprised.gif',
            ':lol:' => 'icon_lol.gif',
            ':mad:' => 'icon_mad.gif',
            ':sad:' => 'icon_sad.gif',
            '8-)' => 'icon_cool.gif',
            '8-O' => 'icon_eek.gif',
            ':-(' => 'icon_sad.gif',
            ':-)' => 'icon_smile.gif',
            ':-?' => 'icon_confused.gif',
            ':-D' => 'icon_biggrin.gif',
            ':-P' => 'icon_razz.gif',
            ':-o' => 'icon_surprised.gif',
            ':-x' => 'icon_mad.gif',
            ':-|' => 'icon_neutral.gif',
            ';-)' => 'icon_wink.gif',
            '8O' => 'icon_eek.gif',
            ':(' => 'icon_sad.gif',
            ':)' => 'icon_smile.gif',
            ':?' => 'icon_confused.gif',
            ':D' => 'icon_biggrin.gif',
            ':P' => 'icon_razz.gif',
            ':o' => 'icon_surprised.gif',
            ':x' => 'icon_mad.gif',
            ':|' => 'icon_neutral.gif',
            ';)' => 'icon_wink.gif',
            ':!:' => 'icon_exclaim.gif',
            ':?:' => 'icon_question.gif',
        );
        
        //移除WordPress4.2版本更新所带来的Emoji前后台钩子同时挂上主题自带的表情路径
        remove_action('wp_head', 'print_emoji_detection_script', 7);
        remove_action('admin_print_scripts', 'print_emoji_detection_script');
        remove_action('wp_print_styles', 'print_emoji_styles');
        remove_action('admin_print_styles', 'print_emoji_styles');
        remove_filter('the_content_feed', 'wp_staticize_emoji');
        remove_filter('comment_text_rss', 'wp_staticize_emoji');
        remove_filter('wp_mail', 'wp_staticize_emoji_for_email');

        add_filter('smilies_src', 'custom_smilie9s_src', 10, 2);
    }

    add_action('init', 'init_smilie9s', 5);

// 文章引用
function Lonesome_insert_posts( $atts, $content = null ){
    extract( shortcode_atts( array(
        'ids' => ''
    ),
        $atts ) );
    global $post;
    $content = '';
    $postids =  explode(',', $ids);
    $inset_posts = get_posts(array('post__in'=>$postids));
    foreach ($inset_posts as $key => $post) {
        setup_postdata( $post );
        $content .=  '
			<div class="wp-embed-post">
			    <a href="'. get_permalink() .'" target="_blank" class="wp-embed-post-img" style="background-image:url(' . get_post_thumbnail() . ')"></a>
			        <a href="'. get_permalink() .'" target="_blank"><span class="wp-embed-post-title">' . get_the_title() . '</span></a><em class="wp-embed-post-excerpt">'.wp_trim_words( get_the_content(), 60, '...' ).'</em>
			        <div class="wp-embed-post-meta">
			        	<span>' . get_the_time('Y年n月j日') . '</span>
			        	<span>' . custom_the_views($post->ID). ' 次浏览</span>
			            <a target="_blank" href="' . get_permalink() . '#comments"> 评论 ' . get_comments_number(). '</a>
			        </div>
			</div>        ';
    }
    wp_reset_postdata();
    return $content;
}
add_shortcode('Lonesome_insert_post', 'Lonesome_insert_posts');

/**
 * 文章浏览次数.
 *
 * @since Pure 1.0
 */
function restyle_text($number) {
    if($number >= 1000) {
        return round($number/1000,2) . "k";   // NB: you will want to round this
    }
    else {
        return $number;
    }
}

function set_post_views() {
    if (!is_singular()) return;
    global $post;
    $post_id = intval($post->ID);
    $count_key = 'views';
    $views = get_post_custom($post_id);
    $views = intval($views['views'][0]);
    if (is_single() || is_page()) {
        if(!update_post_meta($post_id, 'views', ($views + 1))) {
            add_post_meta($post_id, 'views', 1, true);
        }
    }
}
add_action('get_header', 'set_post_views');

function custom_the_views($post_id) {
    $count_key = 'views';
    $views = get_post_custom($post_id);
    $views = intval($views['views'][0]);
    $post_views = intval(post_custom('views'));
    if ($views == '') {
        return 0;
    } else {
        return restyle_text($views);
    }
}
	
// 机器评论验证
	function Lonesome_robot_comment(){
	  if ( !$_POST['no-robot'] && !is_user_logged_in()) {
	     Lonesome_ajax_comment_err('请勾选评论验证按钮后再发表。');
	  }
	}

	add_action('pre_comment_on_post', 'Lonesome_robot_comment');

// 纯英文评论拦截
	function Lonesome_comment_post( $incoming_comment ) {
	  if(!preg_match('/[一-龥]/u', $incoming_comment['comment_content'])){
	    Lonesome_ajax_comment_err('写点汉字吧，博主外语很捉急。');
	  }
	  return( $incoming_comment );
	}

	add_filter('preprocess_comment', 'Lonesome_comment_post');

// 评论框信息上调
	function recover_comment_fields($comment_fields){
	    $comment = array_shift($comment_fields);
	    $comment_fields =  array_merge($comment_fields ,array('comment' => $comment));
	    return $comment_fields;
	}
	add_filter('comment_form_fields','recover_comment_fields');

//搜索结果排除所有页面
	function search_filter_page($query) {
		if ($query->is_search) {
			$query->set('post_type', 'post');
		}
		return $query;
	}
	add_filter('pre_get_posts','search_filter_page');

// 评论楼层
	function Lonesome_comment_floor_css(){
	    global $wp_query;
	    if ( is_singular() ) {
	        global $post;
	        $comments = get_comments( array(
	            'post_id' => get_the_ID(),
	            'orderby' => 'comment_date_gmt',
	            'order' => 'ASC',
	            'status' => 'all',
	        ) );
	        $page = get_query_var('cpage') ? get_query_var('cpage') : get_comment_pages_count($comments);
	    }
	}
	add_action('wp_head','Lonesome_comment_floor_css', 10);

	/**
	功能说明: WordPress缩略图
	更新时间：2016-11-11
	**/
	function Lonesome_is_has_image(){
	    global $post;
	    if( has_post_thumbnail() ) return true;
	    $content = $post->post_content;
	    preg_match_all('/<img.*?(?: |\\t|\\r|\\n)?src=[\'"]?(.+?)[\'"]?(?:(?: |\\t|\\r|\\n)+.*?)?>/sim', $content, $strResult, PREG_PATTERN_ORDER);
	    if(!empty($strResult[1])) return true;
	    return false;
	}
	/**
	功能说明: 获取缩略图地址
	更新时间：2016-11-11
	**/
	function get_post_thumbnail(){
	    global $post;
	    if( has_post_thumbnail() ){
	        $timthumb_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
	        return $timthumb_src[0];
	    } else {
	        $content = $post->post_content;
	        preg_match_all('/<img.*?(?: |\\t|\\r|\\n)?src=[\'"]?(.+?)[\'"]?(?:(?: |\\t|\\r|\\n)+.*?)?>/sim', $content, $strResult, PREG_PATTERN_ORDER);
	        $n = count($strResult[1]);
	        if ($n > 0) {
	            return $strResult[1][0];
	        } else {
	            return false;
	        }
	    }
	}

// 去除多余小工具
	function unregister_default_widgets() {
	    unregister_widget('WP_Widget_Pages');
	    unregister_widget('WP_Widget_Calendar');
	    unregister_widget('WP_Widget_Archives');
	    unregister_widget('WP_Widget_Meta');
	    unregister_widget('WP_Widget_Categories');
	    unregister_widget('WP_Widget_Recent_Posts');
	    unregister_widget('WP_Widget_Recent_Comments');
	    unregister_widget('WP_Widget_RSS');
	    unregister_widget('WP_Widget_Tag_Cloud');
	    unregister_widget('WP_Nav_Menu_Widget');
	}
	add_action('widgets_init', 'unregister_default_widgets');
