<?php
/**
 * 此主题的自定义模板标签。
 *
 * 最终，这里的一些功能可以被核心功能所取代。
 *
 */

/**
 * 当前文章的日期和文章的作者
 */
function Lonesome_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated hidden" datetime="%3$s">%4$s</time>';
	}
	printf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);
}

/**
 * 标签和评论信息
 */
function Lonesome_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		the_tags( '<div class="post-tags">', '', '</div>' );
	}
	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( '留下你的评论', 'Lonesome' ), esc_html__( '1 个评论', 'Lonesome' ), esc_html__( '% 个评论', 'Lonesome' ) );
		echo '</span>';
	}
}

add_filter( 'get_the_archive_title', 'Lonesome_archive_title' );

/**
 * 更改页面的标题
 *
 * @param string $title
 *
 * @return string
 */
function Lonesome_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_home() && ! is_front_page() ) {
		$title = get_the_title( get_option( 'page_for_posts' ) );
	} elseif ( is_search() ) {
		$title = esc_html__( '搜索结果', 'Lonesome' );
	}

	return $title;
}

/**
 * Getter function for Featured Content.
 *
 * @return array An array of WP_Post objects.
 */
function Lonesome_get_featured_posts() {
	return apply_filters( 'Lonesome_get_featured_posts', array() );
}