<?php
/**
 * 关于我——侧边栏小插件
 */
class Lonesome_Widget_About extends WP_Widget {
	/**
	 * Holds widget settings defaults, populated in constructor.
	 * @var array
	 */
	protected $defaults;

	/**
	 * Constructor
	 */
	public function __construct() {
		$this->defaults = array(
			'title'           => '',
			'image'           => '',
			'intro'           => '',
		);

		parent::__construct(
			'Lonesome-about-widget',
			esc_html__( '主题特色：关于我', 'Lonesome' ),
			array(
				'classname' => 'Lonesome-about-widget',
			)
		);
		add_action( 'sidebar_admin_setup', array( $this, 'admin_scripts' ) );
		if ( is_active_widget( false, false, $this->id_base, true ) ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
		}
	}

	/**
	 * Enqueue script for image upload in widgets.
	 */
	public function admin_scripts() {
		wp_enqueue_style( 'Lonesome-widget-image', get_template_directory_uri() . '/css/widget-image.css' );

		wp_enqueue_media();
		wp_enqueue_script( 'Lonesome-widget-image', get_template_directory_uri() . '/js/widget-image.js', array(
			'jquery',
			'media-upload',
			'media-views'
		), '', true );
		wp_localize_script( 'Lonesome-widget-image', 'LonesomeWidgetImage', array(
			'title'  => esc_html__( '选择一张图片', 'Lonesome' ),
			'button' => esc_html__( '插入小部件', 'Lonesome' ),
		) );
	}

	/**
	 * Display widget
	 *
	 * @param array $args Sidebar configuration
	 * @param array $instance Widget settings
	 */
	public function widget( $args, $instance ) {
		$instance = wp_parse_args( $instance, $this->defaults );

		echo $args['before_widget'];
		if ( $title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) ) {
			echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
		}
		if ( $instance['image'] ) {
			echo '<img class="Lonesome-about-image" src="', esc_url( $instance['image'] ), '" alt="">';
		}
		if ( $instance['intro'] ) {
			echo '<div class="Lonesome-about-intro">', wp_kses_post( $instance['intro'] ), '</div>';
		}

		get_template_part( 'template-parts/sidebar-nav' );

		echo $args['after_widget'];
	}

	/**
	 * Update widget
	 *
	 * @param array $new_instance New widget settings
	 * @param array $old_instance Old widget settings
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                    = $old_instance;
		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['image']           = esc_url_raw( $new_instance['image'] );
		$instance['intro']           = sanitize_text_field( $new_instance['intro'] );

		return $instance;
	}

	/**
	 * Display widget settings
	 *
	 * @param array $instance Widget settings
	 *
	 * @return void
	 */
	public function form( $instance ) {
		$instance = wp_parse_args( $instance, $this->defaults );
		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( '标题', 'Lonesome' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>">
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>"><?php esc_html_e( '图像', 'Lonesome' ); ?></label>
			<span class="Lonesome-widget-image">
				<input id="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>" type="text" class="Lonesome-widget-image__input" value="<?php echo esc_attr( $instance['image'] ); ?>">
				<button class="button Lonesome-widget-image__select"><?php esc_html_e( '选择', 'Lonesome' ); ?></button>
				<img src="<?php echo esc_url( $instance['image'] ); ?>" class="Lonesome-widget-image__image<?php echo $instance['image'] ? '' : ' hidden'; ?>">
			</span>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'intro' ) ); ?>"><?php esc_html_e( '简介', 'Lonesome' ); ?></label>
			<textarea id="<?php echo esc_attr( $this->get_field_id( 'intro' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'intro' ) ); ?>" class="widefat"><?php echo esc_textarea( $instance['intro'] ); ?></textarea>
		</p>
		<?php
	}
}
